@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 S[&]T, The Netherlands.
+ * Copyright (C) 2007-2023 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -95,6 +95,7 @@ static coda_mem_record *attribute_record_new(coda_type_record *definition, coda_
     int i;
 
     assert(definition != NULL);
+    assert(!definition->is_union);
     attributes = coda_mem_record_new(definition, NULL);
 
     if (el != coda_element_name_from_xml_name(el))
@@ -208,7 +209,7 @@ static coda_mem_record *attribute_record_new(coda_type_record *definition, coda_
                 return NULL;
             }
             attribute = coda_mem_data_new(definition->field[attribute_index]->type, NULL, (coda_product *)product,
-                                          strlen(attr[2 * i + 1]), (uint8_t *)attr[2 * i + 1]);
+                                          (long)strlen(attr[2 * i + 1]), (uint8_t *)attr[2 * i + 1]);
         }
         if (attribute == NULL)
         {
@@ -543,6 +544,7 @@ static void XMLCALL start_element_handler(void *data, const char *el, const char
     {
         int i;
 
+        assert(!((coda_type_record *)definition)->is_union);
         info->record[info->depth] = coda_mem_record_new((coda_type_record *)definition, info->attributes);
         if (info->record[info->depth] == NULL)
         {
@@ -772,6 +774,7 @@ int coda_xml_parse(coda_xml_product *product)
     else
     {
         assert(product->product_definition->root_type->type_class == coda_record_class);
+        assert(!((coda_type_record *)product->product_definition->root_type)->is_union);
         info.record[0] = coda_mem_record_new((coda_type_record *)product->product_definition->root_type, NULL);
     }
     if (info.record[0] == NULL)
