@@ -17,6 +17,9 @@
 #ifdef CODA_EXPAT_NAME_MANGLE
 
 #define _INTERNAL_trim_to_complete_utf8_characters coda_INTERNAL_trim_to_complete_utf8_characters
+#define testingAccountingGetCountBytesDirect coda_testingAccountingGetCountBytesDirect
+#define testingAccountingGetCountBytesIndirect coda_testingAccountingGetCountBytesIndirect
+#define unsignedCharToPrintable coda_unsignedCharToPrintable
 #define XML_DefaultCurrent coda_XML_DefaultCurrent
 #define XML_ErrorString coda_XML_ErrorString
 #define XML_ExpatVersion coda_XML_ExpatVersion
@@ -48,6 +51,8 @@
 #define XML_ResumeParser coda_XML_ResumeParser
 #define XML_SetAttlistDeclHandler coda_XML_SetAttlistDeclHandler
 #define XML_SetBase coda_XML_SetBase
+#define XML_SetBillionLaughsAttackProtectionActivationThreshold coda_XML_SetBillionLaughsAttackProtectionActivationThreshold
+#define XML_SetBillionLaughsAttackProtectionMaximumAmplification coda_XML_SetBillionLaughsAttackProtectionMaximumAmplification
 #define XML_SetCdataSectionHandler coda_XML_SetCdataSectionHandler
 #define XML_SetCharacterDataHandler coda_XML_SetCharacterDataHandler
 #define XML_SetCommentHandler coda_XML_SetCommentHandler
