@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 S[&]T, The Netherlands.
+ * Copyright (C) 2007-2023 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -51,14 +51,14 @@ int option_quick;
 int option_require_definition;
 int found_errors;
 
-static void print_version()
+static void print_version(void)
 {
     printf("codacheck version %s\n", libcoda_version);
-    printf("Copyright (C) 2007-2022 S[&]T, The Netherlands.\n");
+    printf("Copyright (C) 2007-2023 S[&]T, The Netherlands.\n");
     printf("\n");
 }
 
-static void print_help()
+static void print_help(void)
 {
     printf("Usage:\n");
     printf("    codacheck [-D definitionpath] [<options>] <files>\n");
