@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 S[&]T, The Netherlands.
+ * Copyright (C) 2007-2023 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,6 @@
 
 /* internal CODA functions */
 void coda_cursor_add_to_error_message(const coda_cursor *cursor);
-int coda_cursor_print_path(const coda_cursor *cursor, int (*print)(const char *, ...));
 
 const char *pre[] = { "< ", "> " };
 
@@ -60,14 +59,14 @@ struct
     coda_tree_node *tree;
 } array_key_info;
 
-static void print_version()
+static void print_version(void)
 {
     printf("codacheck version %s\n", libcoda_version);
-    printf("Copyright (C) 2007-2022 S[&]T, The Netherlands.\n");
+    printf("Copyright (C) 2007-2023 S[&]T, The Netherlands.\n");
     printf("\n");
 }
 
-static void print_help()
+static void print_help(void)
 {
     printf("Usage:\n");
     printf("    codacmp [-D definitionpath] [<options>] file1 file2\n");
