@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 S[&]T, The Netherlands.
+ * Copyright (C) 2007-2023 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -499,7 +499,7 @@ static void write_data(FILE *f, int depth, int array_depth, int record_depth)
     }
 }
 
-void export_data_element_to_ascii()
+void export_data_element_to_ascii(void)
 {
     if (first_write_of_data)
     {
